import 'package:flutter/material.dart' as md;

class Theme {
  static bool isDark(md.BuildContext context) {
    return Theme.of(context).brightness == md.Brightness.dark;
  }

  static bool isLight(md.BuildContext context) {
    return Theme.of(context).brightness == md.Brightness.light;
  }

  static md.ThemeData dark() {
    var baseTextStyle = md.TextStyle(
      color: md.Colors.white,
      fontWeight: md.FontWeight.w400,
    );

    return md.ThemeData.dark().copyWith(
      primaryColor: md.Colors.grey[850],
      scaffoldBackgroundColor: md.Colors.grey[900],
      accentColor: md.Colors.blue[800],
      textTheme: md.TextTheme(
        // headers
        headline1: baseTextStyle.copyWith(
          fontSize: 23,
          fontWeight: md.FontWeight.w500,
        ),
        headline2: baseTextStyle.copyWith(
          fontSize: 23,
        ),
        headline3: baseTextStyle.copyWith(
          fontSize: 21,
          fontWeight: md.FontWeight.w500,
        ),
        headline4: baseTextStyle.copyWith(
          fontSize: 21,
        ),
        headline5: baseTextStyle.copyWith(
          fontSize: 19,
          fontWeight: md.FontWeight.w500,
        ),
        headline6: baseTextStyle.copyWith(
          fontSize: 19,
        ),
        // subtitle
        subtitle2: baseTextStyle.copyWith(
          fontSize: 17,
          fontWeight: md.FontWeight.w500,
        ),
        subtitle1: baseTextStyle.copyWith(
          fontSize: 17,
        ),
        // bodyText
        bodyText2: baseTextStyle.copyWith(
          fontSize: 15,
          fontWeight: md.FontWeight.w500,
        ),
        bodyText1: baseTextStyle.copyWith(
          fontSize: 15,
        ),
        // button
        button: baseTextStyle.copyWith(
          fontSize: 15,
          fontWeight: md.FontWeight.w500,
        ),
        // caption
        caption: baseTextStyle.copyWith(
          fontSize: 13,
        ),
        // overline
        overline: baseTextStyle.copyWith(
          fontSize: 13,
        ),
      ),
    );
  }

  static md.ThemeData light() {
    var baseTextStyle = md.TextStyle(
      color: md.Colors.black,
      fontWeight: md.FontWeight.w400,
    );

    return md.ThemeData.light().copyWith(
      primaryColor: md.Colors.white,
      scaffoldBackgroundColor: md.Colors.grey[300],
      accentColor: md.Colors.blue,
      textTheme: md.TextTheme(
        // headers
        headline1: baseTextStyle.copyWith(
          fontSize: 23,
          fontWeight: md.FontWeight.w500,
        ),
        headline2: baseTextStyle.copyWith(
          fontSize: 23,
        ),
        headline3: baseTextStyle.copyWith(
          fontSize: 21,
          fontWeight: md.FontWeight.w500,
        ),
        headline4: baseTextStyle.copyWith(
          fontSize: 21,
        ),
        headline5: baseTextStyle.copyWith(
          fontSize: 19,
          fontWeight: md.FontWeight.w500,
        ),
        headline6: baseTextStyle.copyWith(
          fontSize: 19,
        ),
        // subtitle
        subtitle2: baseTextStyle.copyWith(
          fontSize: 17,
          fontWeight: md.FontWeight.w500,
        ),
        subtitle1: baseTextStyle.copyWith(
          fontSize: 17,
        ),
        // bodyText
        bodyText2: baseTextStyle.copyWith(
          fontSize: 15,
          fontWeight: md.FontWeight.w500,
        ),
        bodyText1: baseTextStyle.copyWith(
          fontSize: 15,
        ),
        // button
        button: baseTextStyle.copyWith(
          fontSize: 15,
          fontWeight: md.FontWeight.w500,
        ),
        // caption
        caption: baseTextStyle.copyWith(
          fontSize: 13,
        ),
        // overline
        overline: baseTextStyle.copyWith(
          fontSize: 13,
        ),
      ),
    );
  }

  static md.ThemeData of(md.BuildContext context) {
    return md.Theme.of(context).brightness == md.Brightness.light
        ? light()
        : dark();
  }
}
