import 'package:flutter/material.dart' as md;
import 'package:flx_ui/flx_ui.dart';

class FlxApp extends StatelessWidget {
  final String title;

  final md.ThemeMode? themeMode;
  final md.ThemeData? lightTheme;
  final md.ThemeData? darkTheme;

  final Locale? locale;
  final List<Locale> locales;
  final List<LocalizationsDelegate<dynamic>>? delegates;

  final Map<String, Widget Function(BuildContext)> routes;
  final String? initialRoute;

  final Widget? initialWidget;

  const FlxApp({
    Key? key,
    this.title = '',
    this.themeMode,
    this.lightTheme,
    this.darkTheme,
    this.locale,
    this.locales = const [Locale('en', 'US')],
    this.routes = const {},
    this.delegates,
    this.initialRoute,
    this.initialWidget,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return md.MaterialApp(
      key: key,
      title: title,
      theme: lightTheme ?? Theme.light(),
      darkTheme: darkTheme ?? Theme.dark(),
      themeMode: themeMode,
      locale: locale,
      supportedLocales: locales,
      localizationsDelegates: delegates,
      routes: routes,
      initialRoute: initialRoute,
      home: initialWidget,
    );
  }
}
