import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart' as material;

class TextField extends StatelessWidget {
  final double? width;

  final String? placeholder;

  final bool? isConceal;

  final TextEditingController? controller;

  const TextField({
    Key? key,
    this.width,
    this.placeholder,
    this.isConceal,
    this.controller,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GetBuilder<TextFieldController>(
      init: TextFieldController(controller ?? TextEditingController()),
      global: false,
      builder: (TextFieldController controller) => GestureDetector(
        onTap: () => controller.onTap(),
        child: SizedBox(
          width: width,
          height: 42,
          child: FlatCard(
            child: AnimatedContainer(
              duration: Duration(milliseconds: 350),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(11),
                border: Border.all(
                  width: controller.isFocus ? 2 : 0,
                  color: controller.isFocus
                      ? ColorTheme.accent(context)
                      : Colors.transparent,
                ),
              ),
              child: AnimatedPadding(
                duration: Duration(milliseconds: 350),
                padding: EdgeInsets.symmetric(
                  horizontal: controller.isFocus ? 14.0 : 16.0,
                ),
                child: Center(
                  child: material.TextField(
                    controller: controller.textEditingController,
                    focusNode: controller.focusNode,
                    scrollPhysics: const BouncingScrollPhysics(),
                    obscureText: isConceal ?? false,
                    decoration: material.InputDecoration.collapsed(
                      hintText: placeholder ?? '',
                    ),
                    style: TextTheme.field(context),
                  ),
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
